@@ -6,7 +6,7 @@ use warnings;
 use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.22';
+our $VERSION    = '0.23';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -130,7 +130,7 @@ compression modules available on CPAN.  These are the results on a MacBook
 
 =head1 SEE ALSO
 
-L<http://code.google.com/p/lz4/>
+L<http://cyan4973.github.io/lz4/>
 
 =head1 REQUESTS AND BUGS
 
@@ -173,7 +173,7 @@ L<http://search.cpan.org/dist/Compress-LZ4/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2015 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2012-2016 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
